@@ -144,7 +144,7 @@ class UdpSession(object):
         finally:
             cls.buffer_arr = []
             if packet_type == PacketTypeEnum.TX_END:
-                TraceContextManager.end(ctx.thread_id)
+                TraceContextManager.end(ctx.id)
 
     @classmethod
     def get(cls):
