@@ -24,6 +24,10 @@ class TraceContextManager(object):
     def keys(cls):
         return cls.entry.keys()
     
+    @classmethod
+    def size(cls):
+        return cls.entry.size()
+    
     @classmethod
     def getActiveCount(cls):
         act = [0 for _ in range(3)]
@@ -79,27 +83,21 @@ class TraceContextManager(object):
             cls.local.context = None
         return cls.local.context
     
+    @classmethod
+    def setLocalContext(cls, o):
+        o.thread = threading.current_thread()
+        o.thread_id = o.thread.ident
+        cls.local.context = o
+        
     @classmethod
     def getId(cls):
         uuid1 = uuid.uuid1(TraceContextManager.node, TraceContextManager.clock_seq)
         key = (uuid1.int >> 64 & 0xffffffffffffffff) ^ (uuid1.int << 64 & 0xffffffffffffffff)
         return c_int64(key).value
 
-    @classmethod
-    def getCurrentKey(cls):
-        thread_id = cls.getCurrentThreadId()
-        pid = os.getpid()
-        dout = DataOutputX()
-        dout.writeInt(pid)
-        dout.writeInt(0)
-        din = DataInputX(dout.buffer.getvalue())
-        key = din.readLong() + thread_id
-
-        return key
-
     @classmethod
     def start(cls, o):
-        key = cls.getCurrentKey()
+        key = o.id
         cls.local.context = o
         cls.entry.put(key, o)
 
@@ -107,13 +105,11 @@ class TraceContextManager(object):
     
     @classmethod
     def parseThreadId(cls, key):
-        pid = os.getpid()
-        dout = DataOutputX()
-        dout.writeInt(pid)
-        dout.writeInt(0)
-        din = DataInputX(dout.buffer.getvalue())
-        thread_id = key - din.readLong()
-        return thread_id, pid
+        o = cls.entry.get(key)
+        if o:
+            return o.thread_id, o.pid
+        else:
+            return None, None
     
     @classmethod
     def end(cls, key):
